==> tabular-data-gwt-service-2.5.0-20141211.112508-173-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/task/JobS.java <==
package org.gcube.portlets.user.td.gwtservice.shared.task;

import java.io.Serializable;
import java.util.ArrayList;

import org.gcube.portlets.user.td.gwtservice.shared.tr.table.Validations;

/**
 * 
 * @author "Giancarlo Panichi"
 * 
 */
public class JobS implements Serializable {

	private static final long serialVersionUID = 4502877601374000292L;

	protected String id; // For grid only
	protected float progress;
	protected String humaReadableStatus;
	protected String description;
	protected InvocationS invocation;
	protected ArrayList<Validations> validations;
	protected Throwable errorMessage;
	protected WorkerState workerState;
	protected ArrayList<ValidationsJobS> validationsJobS;

	public JobS() {

	}

	/**
	 * For Validation Tasks
	 * 
	 * @param id
	 * @param progress
	 * @param humaReadableStatus
	 * @param description
	 * @param validations
	 * @param invocation
	 */
	public JobS(String id, float progress, String humaReadableStatus,
			String description, ArrayList<Validations> validations,
			InvocationS invocation) {
		this.id = id;
		this.progress = progress;
		this.humaReadableStatus = humaReadableStatus;
		this.description = description;
		this.validations = validations;
		this.invocation = invocation;
		validationsJobS = null;
		errorMessage = null;
		validationsJobS = null;
	}

	/**
	 * For Operation Monitor
	 * 
	 * @param id
	 * @param progress
	 * @param humaReadableStatus
	 * @param description
	 * @param errorMessage
	 * @param workerState
	 * @param validationsJobs
	 */
	public JobS(String id, float progress, String humaReadableStatus,
			String description, WorkerState workerState,
			Throwable errorMessage, ArrayList<ValidationsJobS> validationsJobs) {
		this.id = id;
		this.progress = progress;
		this.humaReadableStatus = humaReadableStatus;
		this.description = description;
		this.validationsJobS = validationsJobs;
		this.errorMessage = errorMessage;
		this.workerState = workerState;
		this.validations = null;
		this.invocation = null;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public float getProgress() {
		return progress;
	}

	public void setProgress(float progress) {
		this.progress = progress;
	}

	public String getHumaReadableStatus() {
		return humaReadableStatus;
	}

	public void setHumaReadableStatus(String humaReadableStatus) {
		this.humaReadableStatus = humaReadableStatus;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public ArrayList<Validations> getValidations() {
		return validations;
	}

	public void setValidations(ArrayList<Validations> validations) {
		this.validations = validations;
	}

	public InvocationS getInvocation() {
		return invocation;
	}

	public void setInvocation(InvocationS invocation) {
		this.invocation = invocation;
	}

	public Throwable getErrorMessage() {
		return errorMessage;
	}

	public void setErrorMessage(Throwable errorMessage) {
		this.errorMessage = errorMessage;
	}

	public WorkerState getWorkerState() {
		return workerState;
	}

	public void setWorkerState(WorkerState workerState) {
		this.workerState = workerState;
	}

	public ArrayList<ValidationsJobS> getValidationsJobS() {
		return validationsJobS;
	}

	public void setValidationsJobS(ArrayList<ValidationsJobS> validationsJobS) {
		this.validationsJobS = validationsJobS;
	}

	@Override
	public String toString() {
		return "JobS [id=" + id + ", progress=" + progress
				+ ", humaReadableStatus=" + humaReadableStatus
				+ ", description=" + description + ", invocation=" + invocation
				+ ", validations=" + validations + ", errorMessage="
				+ errorMessage + ", workerState=" + workerState
				+ ", validationsJobS=" + validationsJobS + "]";
	}

}

==> tabular-data-gwt-service-2.8.0-20150803.123833-24-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/task/JobS.java <==
package org.gcube.portlets.user.td.gwtservice.shared.task;

import java.io.Serializable;
import java.util.ArrayList;

import org.gcube.portlets.user.td.gwtservice.shared.tr.table.Validations;

/**
 * 
 * @author giancarlo
 * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class JobS implements Serializable {

	private static final long serialVersionUID = 4502877601374000292L;

	private String id; // For grid only
	private float progress;
	private String humaReadableStatus;
	private JobSClassifier jobClassifier;
	private String description;
	private InvocationS invocation;
	private ArrayList<Validations> validations;
	private Throwable errorMessage;
	private WorkerState workerState;
	private ArrayList<ValidationsJobS> validationsJobS;

	public JobS() {

	}

	/**
	 * For Validation Tasks
	 * 
	 * @param id
	 * @param progress
	 * @param humaReadableStatus
	 * @param description
	 * @param validations
	 * @param invocation
	 */
	public JobS(String id, float progress, String humaReadableStatus,
			JobSClassifier jobClassifier, String description, ArrayList<Validations> validations,
			InvocationS invocation) {
		this.id = id;
		this.progress = progress;
		this.humaReadableStatus = humaReadableStatus;
		this.jobClassifier=jobClassifier;
		this.description = description;
		this.validations = validations;
		this.invocation = invocation;
		validationsJobS = null;
		errorMessage = null;
		validationsJobS = null;
	}

	/**
	 * For Operation Monitor
	 * 
	 * @param id
	 * @param progress
	 * @param humaReadableStatus
	 * @param description
	 * @param errorMessage
	 * @param workerState
	 * @param validationsJobs
	 */
	public JobS(String id, float progress, String humaReadableStatus,
			JobSClassifier jobClassifier,String description, WorkerState workerState,
			Throwable errorMessage, ArrayList<ValidationsJobS> validationsJobs) {
		this.id = id;
		this.progress = progress;
		this.humaReadableStatus = humaReadableStatus;
		this.jobClassifier=jobClassifier;
		this.description = description;
		this.validationsJobS = validationsJobs;
		this.errorMessage = errorMessage;
		this.workerState = workerState;
		this.validations = null;
		this.invocation = null;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public float getProgress() {
		return progress;
	}

	public void setProgress(float progress) {
		this.progress = progress;
	}

	public String getHumaReadableStatus() {
		return humaReadableStatus;
	}

	public void setHumaReadableStatus(String humaReadableStatus) {
		this.humaReadableStatus = humaReadableStatus;
	}

	public JobSClassifier getJobClassifier() {
		return jobClassifier;
	}

	public void setJobClassifier(JobSClassifier jobClassifier) {
		this.jobClassifier = jobClassifier;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public ArrayList<Validations> getValidations() {
		return validations;
	}

	public void setValidations(ArrayList<Validations> validations) {
		this.validations = validations;
	}

	public InvocationS getInvocation() {
		return invocation;
	}

	public void setInvocation(InvocationS invocation) {
		this.invocation = invocation;
	}

	public Throwable getErrorMessage() {
		return errorMessage;
	}

	public void setErrorMessage(Throwable errorMessage) {
		this.errorMessage = errorMessage;
	}

	public WorkerState getWorkerState() {
		return workerState;
	}

	public void setWorkerState(WorkerState workerState) {
		this.workerState = workerState;
	}

	public ArrayList<ValidationsJobS> getValidationsJobS() {
		return validationsJobS;
	}

	public void setValidationsJobS(ArrayList<ValidationsJobS> validationsJobS) {
		this.validationsJobS = validationsJobS;
	}

	@Override
	public String toString() {
		return "JobS [id=" + id + ", progress=" + progress
				+ ", humaReadableStatus=" + humaReadableStatus
				+ ", jobClassifier=" + jobClassifier + ", description="
				+ description + ", invocation=" + invocation + ", validations="
				+ validations + ", errorMessage=" + errorMessage
				+ ", workerState=" + workerState + ", validationsJobS="
				+ validationsJobS + "]";
	}

	

}
